@@ -4,7 +4,7 @@ use Imager;
 use vars qw($VERSION @ISA);
 
 BEGIN {
-  $VERSION = "0.003";
+  $VERSION = "0.004";
 
   require XSLoader;
   XSLoader::load('Imager::File::WEBP', $VERSION);
@@ -128,6 +128,10 @@ number from 0 (bad) to 100 (better).  Default: 80.
 
 =back
 
+If Imager::File::WEBP was built with Imager 1.010 then EXIF metadata
+will also be read from the file.  See the description at
+L<Imager::Files/JPEG>.
+
 =head2 Animation tags
 
 These only have meaning for files with more than one image.
@@ -165,7 +169,7 @@ stored as the even number just below.  Default: 0.
 
 =item *
 
-C<webp_duraton> - duration of the frame in milliseconds.  Default:
+C<webp_duration> - duration of the frame in milliseconds.  Default:
 100.
 
 =item *
@@ -219,10 +223,10 @@ libwebp 0.5.0 or later and the libwebpmux distributed with libwebp.
 These aren't intended immediately, but are possible future
 enhancements.
 
-=head2 Compression level support for lossless
+=head2 Compression level support for lossless images
 
-This is complicated by the simple lossless API doesn't support it
-(while lossy does.)
+The simple lossless API doesn't include a compression level parameter,
+which complicates this.  It may not be worth doing anyway.
 
 =head2 Parse EXIF metadata
 
